//
//  DXRssParser.h
//  DXSearchers
//
//  Created by Oliver Kahrmann on 01.04.11.
//  Copyright 2011 DHELIXSoft. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "DXRssChannel.h"
#import "DXRssParserExceptions.h"
#import "DXExceptionManager.h"
#import "DXRssItem.h"


@interface DXRssParser : NSObject {
	NSXMLDocument *_xmlDoc;
	DXRssChannel *_parsedChannel;
	NSMutableArray *_exceptions;
}
-(id)initWithContentsOfURL:(NSURL*)url error:(NSError**)error;
-(id)initWithData:(NSData*)data error:(NSError**)error;
-(id)initWithString:(NSString*)string error:(NSError**)error;
-(id)initWithCXMLDocument:(NSXMLDocument *)xmlDoc;

- (BOOL)isValidDay:(NSString *)dayString;
- (BOOL)isValidHour:(NSString *)hourString;

- (DXRssCloudInfo *)parseCloud:(NSXMLElement *)xmlElement;
- (DXRssImage *)parseImage:(NSXMLElement *)xmlElement;
- (DXRssTextInput *)parseTextInput:(NSXMLElement *)xmlElement;
- (DXRssEnclosure *)parseEnclosure:(NSXMLElement *)xmlElement;
- (DXRssGuid *)parseGuid:(NSXMLElement *)xmlElement;
- (DXRssItem *)parseItem:(NSXMLElement *)xmlElement;
- (NSString *)outputDateString:(NSDate *)date;
- (NSDate *)parseDateString:(NSString *)dateString;
- (bool)validateUrlString:(NSString *)urlString;


- (NSXMLDocument *)xmlDoc;
- (void)setXmlDoc:(NSXMLDocument *)value;

- (DXRssChannel *)parsedChannel;
- (void)setParsedChannel:(DXRssChannel *)value;

- (NSArray *)exceptions;
- (unsigned)countOfExceptions;
- (id)objectInExceptionsAtIndex:(unsigned)theIndex;
- (void)getExceptions:(id *)objsPtr range:(NSRange)range;
- (void)insertObject:(id)obj inExceptionsAtIndex:(unsigned)theIndex;
- (void)removeObjectFromExceptionsAtIndex:(unsigned)theIndex;
- (void)replaceObjectInExceptionsAtIndex:(unsigned)theIndex withObject:(id)obj;



@end
